.. django-allauth documentation master file, created by
   sphinx-quickstart on Wed Jun  6 22:58:42 2012.

.. include:: ../README.rst
    :end-before: .. end-welcome

Contents
********

.. toctree::
   :maxdepth: 2

   introduction/index
   installation/index
   account/index
   socialaccount/index
   mfa/index
   common/index
   project/index
   faq
   release-notes/index


Indices and tables
******************

* :ref:`genindex`
* :ref:`search`
